@@ -12,19 +12,16 @@
 
 #include <KConfigDialogManager>
 #include <KCoreConfigSkeleton>
-#include <KPageWidgetModel>
 #include <KHelpClient>
 
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QIcon>
-#include <QLayout>
 #include <QPushButton>
 #include <QMap>
-#include <QCoreApplication>
-#include <QDesktopServices>
 #include <QScrollArea>
+#include <QVBoxLayout>
 
 #include <algorithm>
 
@@ -200,11 +197,11 @@ KPageWidgetItem *ConfigDialog::ConfigDialogPrivate::addPageInternal(KPageWidgetI
                                                                     const QString &pixmapName,
                                                                     const QString &header)
 {
-    QWidget *frame = new QWidget(q);
-    QVBoxLayout *boxLayout = new QVBoxLayout(frame);
+    auto *frame = new QWidget(q);
+    auto *boxLayout = new QVBoxLayout(frame);
     boxLayout->setContentsMargins(0, 0, 0, 0);
 
-    QScrollArea *scroll = new QScrollArea(q);
+    auto *scroll = new QScrollArea(q);
     scroll->setFrameShape(QFrame::NoFrame);
     scroll->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     scroll->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
@@ -213,7 +210,7 @@ KPageWidgetItem *ConfigDialog::ConfigDialogPrivate::addPageInternal(KPageWidgetI
     scroll->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding );
 
     boxLayout->addWidget(scroll);
-    KPageWidgetItem *item = new KPageWidgetItem(frame, itemName);
+    auto *item = new KPageWidgetItem(frame, itemName);
     item->setHeader(header);
     if (!pixmapName.isEmpty()) {
         item->setIcon(QIcon::fromTheme(pixmapName));
@@ -312,7 +309,7 @@ void ConfigDialog::ConfigDialogPrivate::_k_updateButtons()
 
     setRestoreDefaultsButtonEnabled(!is_default);
 
-    emit q->widgetModified();
+    Q_EMIT q->widgetModified();
     only_once = false;
 }
 
@@ -320,7 +317,7 @@ void ConfigDialog::ConfigDialogPrivate::_k_settingsChangedSlot()
 {
     // Update the buttons
     _k_updateButtons();
-    emit q->settingsChanged(q->objectName());
+    Q_EMIT q->settingsChanged(q->objectName());
 }
 
 void ConfigDialog::showEvent(QShowEvent *e)
